Check that all columns are present in a table
check_that_columns_exist.RdCheck that all columns are present in a table, raises exception if any columns are missing
check_that_columns_exist.RdCheck that all columns are present in a table, raises exception if any columns are missing