Replicate horizontal grid lines
geom_grid_hlines.RdReplicate horizontal grid lines that are hidden by stripes.
Usage
geom_grid_hlines(
mapping = NULL,
data = NULL,
stat = "identity",
position = "identity",
...,
show.legend = NA,
inherit.aes = TRUE,
color = NULL
)Arguments
- mapping
Set of aesthetic mappings created by
aes(). If specified andinherit.aes = TRUE(the default), it is combined with the default mapping at the top level of the plot. You must supply mapping if there is no plot mapping.- data
The data to be displayed in this layer.
- stat
The statistical transformation to use on the data for this layer.
- position
A position adjustment to use on the data for this layer.
- ...
Other arguments passed on to
layer()'s params argument.- show.legend
logical. Should this layer be included in the legends?
- inherit.aes
If
FALSE, overrides the default aesthetics, rather than combining with them.- color
Line color, if
NULLtheme panel grid line color is used.
Examples
stripes_df <- data.frame(x = c(1, 2, 3), xend = c(2, 3, 4))
ggplot2::ggplot(stripes_df) +
geom_gradient_vstripe(ggplot2::aes(x = x, xend = xend)) +
geom_grid_hlines()