Vertical stripe with constant fill
geom_vstripe_flip.RdDisplays a vertical stripe that spans the entire height of the plot for each pair of x and xend values. Optional alpha defaults to 1.
Usage
geom_vstripe_flip(
mapping = NULL,
data = NULL,
stat = "identity",
position = "identity",
...,
show.legend = NA,
inherit.aes = FALSE
)Arguments
- mapping
Set of aesthetic mappings created by
aes(). If specified andinherit.aes = TRUE(the default), it is combined with the default mapping at the top level of the plot. You must supply mapping if there is no plot mapping.- data
The data to be displayed in this layer.
- stat
The statistical transformation to use on the data for this layer.
- position
A position adjustment to use on the data for this layer.
- ...
Other arguments passed on to
layer()'s params argument.- show.legend
logical. Should this layer be included in the legends?
- inherit.aes
If
FALSE, overrides the default aesthetics, rather than combining with them.